==> adsprod-facade-2.7.1-sources.jar: com/bxm/adsprod/facade/award/UserAwardVo.java <==
package com.bxm.adsprod.facade.award;

import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.util.Date;

/**
 * 用户抽奖记录查询vo
 *
 * @ClassName UserAwardDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/7/26 17:52
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/7/26 17:52
 **/
public class UserAwardVo implements Serializable{
    private static final long serialVersionUID = -1139378840381304037L;

    /**
     * 礼券ID
     *
     * @mbg.generated
     */
    private Long ticketId;

    /**
     * 礼券链接
     *
     * @mbg.generated
     */
    private String ticketLink;

    /**
     * 素材名称
     *
     * @mbg.generated
     */
    private String assetName;

    /**
     * 素材图片
     *
     * @mbg.generated
     */
    private String assetImg;

    /**
     * 素材ID
     *
     * @mbg.generated
     */
    private Long assetId;

    /**
     * 素材简介
     *
     * @mbg.generated
     */
    private String assetIntro;

    public Long getTicketId() {
        return ticketId;
    }

    public void setTicketId(Long ticketId) {
        this.ticketId = ticketId;
    }

    public String getTicketLink() {
        return ticketLink;
    }

    public void setTicketLink(String ticketLink) {
        this.ticketLink = ticketLink;
    }

    public String getAssetName() {
        return assetName;
    }

    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }

    public String getAssetImg() {
        return assetImg;
    }

    public void setAssetImg(String assetImg) {
        this.assetImg = assetImg;
    }

    public Long getAssetId() {
        return assetId;
    }

    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }

    public String getAssetIntro() {
        return assetIntro;
    }

    public void setAssetIntro(String assetIntro) {
        this.assetIntro = assetIntro;
    }
}

==> adsprod-facade-3.3.6.16-sources.jar: com/bxm/adsprod/facade/award/UserAwardVo.java <==
package com.bxm.adsprod.facade.award;

import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.util.Date;

/**
 * 用户抽奖记录查询vo
 *
 * @ClassName UserAwardDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/7/26 17:52
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/7/26 17:52
 **/
public class UserAwardVo implements Serializable{
    private static final long serialVersionUID = -1139378840381304037L;

    /**
     * 礼券ID
     *
     * @mbg.generated
     */
    private Long ticketId;

    /**
     * 礼券链接
     *
     * @mbg.generated
     */
    private String ticketLink;

    /**
     * 素材名称
     *
     * @mbg.generated
     */
    private String assetName;

    /**
     * 素材图片
     *
     * @mbg.generated
     */
    private String assetImg;

    /**
     * 素材ID
     *
     * @mbg.generated
     */
    private Long assetId;

    /**
     * 素材简介
     *
     * @mbg.generated
     */
    private String assetIntro;

    /**
     * 现金奖状态  0 :待领取  1已发放  2：已放弃
     */
    private Integer cashAwardStatus;

    /**
     * 现金奖订单号
     */
    private String ordernum;

    /**
     * 现金金额
     */
    private Double cashAmount;

    /**
     * 现金奖截止日期
     */
    private String cashExpireDate;


    /**
     * 奖品发放类型 0.线下发奖 1.实时现金
     */
    private Integer awardSendType;


    public Long getTicketId() {
        return ticketId;
    }

    public void setTicketId(Long ticketId) {
        this.ticketId = ticketId;
    }

    public String getTicketLink() {
        return ticketLink;
    }

    public void setTicketLink(String ticketLink) {
        this.ticketLink = ticketLink;
    }

    public String getAssetName() {
        return assetName;
    }

    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }

    public String getAssetImg() {
        return assetImg;
    }

    public void setAssetImg(String assetImg) {
        this.assetImg = assetImg;
    }

    public Long getAssetId() {
        return assetId;
    }

    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }

    public String getAssetIntro() {
        return assetIntro;
    }

    public void setAssetIntro(String assetIntro) {
        this.assetIntro = assetIntro;
    }

    public Integer getCashAwardStatus() {
        return cashAwardStatus;
    }

    public void setCashAwardStatus(Integer cashAwardStatus) {
        this.cashAwardStatus = cashAwardStatus;
    }

    public String getOrdernum() {
        return ordernum;
    }

    public void setOrdernum(String ordernum) {
        this.ordernum = ordernum;
    }

    public Double getCashAmount() {
        return cashAmount;
    }

    public void setCashAmount(Double cashAmount) {
        this.cashAmount = cashAmount;
    }

    public String getCashExpireDate() {
        return cashExpireDate;
    }

    public void setCashExpireDate(String cashExpireDate) {
        this.cashExpireDate = cashExpireDate;
    }

    public Integer getAwardSendType() {
        return awardSendType;
    }

    public void setAwardSendType(Integer awardSendType) {
        this.awardSendType = awardSendType;
    }
}
